@@ -3,15 +3,17 @@
 """combine_intensities.py: takes data from the parser and combines the mods and intensities"""
 
 import csv
+import logging
 import os
 import pandas as pd
 from re import finditer, match, findall
 from time import sleep
+
 try:
     from .download_uniprot_AS import download_AS_file
     from .parse_mascot import compile_data_mascot
     from .parse_MaxQuant import compile_data_maxquant, compile_localization_data_maxquant, get_MQ_PTMs
-    from .parse_generic import compile_data_generic, get_PTMs
+    from .parse_generic import compile_data_generic, compile_localization_data_generic, get_PTMs
     from .sparql import process_sparql_output, sparql_request
     from .proteoSushi_constants import cleave_rules, annotation_type_dict, secondary_annotations
     from .ps_utilities import clean_localization_pep_seq, clean_pep_seq, parse_mascot, load_pepdict, parse_maxquant_summary
@@ -19,7 +21,7 @@ except ImportError:
     from download_uniprot_AS import download_AS_file
     from parse_mascot import compile_data_mascot
     from parse_MaxQuant import compile_data_maxquant, compile_localization_data_maxquant, get_MQ_PTMs
-    from parse_generic import compile_data_generic, get_PTMs
+    from parse_generic import compile_data_generic, compile_localization_data_generic, get_PTMs
     from sparql import process_sparql_output, sparql_request
     from proteoSushi_constants import cleave_rules, annotation_type_dict, secondary_annotations
     from ps_utilities import clean_localization_pep_seq, clean_pep_seq, parse_mascot, load_pepdict, parse_maxquant_summary
@@ -366,7 +368,8 @@ def __compress_annotations(annotation_list: list) -> list:
 
 
 def batch_write(batch_results: list, search_engine: str, user_PTMs: list, use_quant: bool,
-                intensity_method: str, intensity_dict: dict, add_annotation: bool, sparql_input: list):
+                intensity_method: str, intensity_dict: dict, add_annotation: bool, sparql_input: list,
+                use_target_list: bool):
     """Write a batch to the output to save memory (RAM)
     Arguments:
         batch_results {list} -- a portion of the results to be written
@@ -376,12 +379,19 @@ def batch_write(batch_results: list, search_engine: str, user_PTMs: list, use_qu
         intensity_method {str} -- whether to sum or average the quant
         intensity_dict {dict} -- a dictionary that connects site info to quant
         add_annotation {bool} -- whether to provide uniprot annotations to the results
+        sparql_input {list} -- data needed to get uniprot annotations
+        use_target_list {bool} -- whether the user chose to use a gene list to affect matches
     Returns:
         list -- row to write
     """
     writable_rows = list()
     if add_annotation:
         sparql_dict = batch_annotate(sparql_input)
+        if isinstance(sparql_dict, int) and sparql_dict == 502:
+            return 502
+        if isinstance(sparql_dict, int) and sparql_dict == 4:
+            return 4
+        
     # This builds the rollup output file depending on what the user chose
     for i in sorted(batch_results, key=lambda r: r[0]):
         if search_engine == "maxquant":
@@ -398,6 +408,8 @@ def batch_write(batch_results: list, search_engine: str, user_PTMs: list, use_qu
                 N = intensity_dict[f"{i[6]}|{i[0].upper()}|{i[1]}"][-1]
                 intensities = intensity_dict[f"{i[6]}|{i[0].upper()}|{i[1]}"][:-1]
                 writable_row += [float(x)/N for x in intensities]
+        if not use_target_list:
+            writable_row = writable_row[:4] + writable_row[5:]
         if add_annotation:
             try:
                 compressed_annotations = __compress_annotations(sparql_dict[i[8].split(' ')[0] + '|' + str(i[1])])
@@ -425,6 +437,8 @@ def batch_annotate(sparql_input: list) -> dict:
     # Separates the input into batches then sends those batches
     while i + batch <= len(sparql_input):
         # Makes the request and sends it to uniprot
+        #print(f"\nInput range: {i}-{i+batch},\nInput list = {sparql_input[i:i+batch]}")
+        logging.debug(f"Input range: {i}-{i+batch},\nInput list = {sparql_input[i:i+batch]}")
         batch_output = sparql_request(sparql_input[i:i+batch])
 
         #If there is a 502 error, send that to the GUI to display
@@ -436,15 +450,23 @@ def batch_annotate(sparql_input: list) -> dict:
             #print("\033[91m {}\033[00m".format(f"Lines {i+2} to {i+batch+1} not annotated!"))
             i += batch
             continue
-
+        #print(f"\nannotations are:\n{batch_output}")
+        logging.debug(f"Annotations are:\n{batch_output}")
         # This processes and combines the annotations to 1 per site
+        #print(f"\nIn batch_annotate uniprot annotation is {type(batch_output)}")
+        logging.debug(f"In batch_annotate uniprot annotation is {type(batch_output)}")
         sparql_output, sparql_dict = process_sparql_output(batch_output, sparql_dict)
+        #print(sparql_output)
+        if isinstance(sparql_output, int) and sparql_output == 4:
+            return 4
         if not sparql_output:
             #print("\033[91m {}\033[00m".format(f"Lines {i+2} to {i+batch+1} not annotated!"))
             i += batch
             continue
         i += batch
         results_annotated += batch
+        #print("\nBatch processed successfully!")
+        logging.debug("Batch processed successfully!")
     batch_output = sparql_request(sparql_input[i:])
 
     #If there is a 502 error, send that to the GUI to display
@@ -456,6 +478,8 @@ def batch_annotate(sparql_input: list) -> dict:
         pass
     else:
         sparql_output, sparql_dict = process_sparql_output(batch_output, sparql_dict)
+        if isinstance(sparql_output, int) and sparql_output == 4:
+            return 4
         if not sparql_output:
             #print("\033[91m {}\033[00m".format(f"Lines {i+2} to {i+batch+1} not annotated!"))
             pass
@@ -487,9 +511,19 @@ def rollup(search_engine: str, search_engine_filepath: str, use_target_list: boo
     Returns:
         int -- possible error flag
     """
+    print("Preparing data for rollup...\n")
+    logging.info(f"Search Engine is {search_engine}")
+    logging.info(f"Localization threshold is {str(localization_threshold)}")
     if search_engine == "generic":
-        sequence_index, modified_sequence_index, mod_dict, intensity_start, data_filename, \
-            var_mod_dict = compile_data_generic(search_engine_filepath, user_PTMs, cleave_rules[protease])
+        if not localization_threshold is None:
+            sequence_index, modified_sequence_index, localization_indices, mod_dict, intensity_start, \
+                data_filename = compile_localization_data_generic(search_engine_filepath, 
+                                                                  user_PTMs, 
+                                                                  cleave_rules[protease],
+                                                                  localization_threshold)
+        else:
+            sequence_index, modified_sequence_index, mod_dict, intensity_start, data_filename, \
+                var_mod_dict = compile_data_generic(search_engine_filepath, user_PTMs, cleave_rules[protease])
         data_file = open(data_filename, 'r')
         tsv_reader = csv.reader(data_file, quotechar='"')
         if intensity_start is None and use_quant:
@@ -546,11 +580,16 @@ def rollup(search_engine: str, search_engine_filepath: str, use_target_list: boo
     batch_size = 100
     unmatched_sequences = []
 
+    print("Beginning PTM site rollup")
+
     # Prints out the completed rollup with annotations from Uniprot (if requested)
     with open(output_filename, 'w', newline = '') as w1:
         out_writer = csv.writer(w1)
-        header2 = ["Gene", "Site", "Protein_Name", "Shared_Genes", "Target_Genes", "Peptide_Sequence", 
-            "Peptide_Modified_Sequence", "Annotation_Score", "Uniprot_Accession_ID"]
+        header2 = ["Gene", "Site", "Protein_Name", "Shared_Genes"]
+        if use_target_list:
+            header2 += ["Target_Genes"] 
+        header2 += ["Peptide_Sequence", "Peptide_Modified_Sequence", "Annotation_Score", 
+                    "Uniprot_Accession_ID"]
         if use_quant:
             if search_engine == "mascot":
                 header2 += [header[intensity_start] + f" ({intensity_method})"]
@@ -573,7 +612,12 @@ def rollup(search_engine: str, search_engine_filepath: str, use_target_list: boo
         for row in tsv_reader:
             if len(gene_results) >= batch_size:
                 writable_rows = batch_write(gene_results, search_engine, user_PTMs, use_quant, 
-                                                intensity_method, intensity_dict, add_annotation, sparql_input)
+                                            intensity_method, intensity_dict, add_annotation, 
+                                            sparql_input, use_target_list)
+                if isinstance(writable_rows, int) and writable_rows == 502:
+                    return 502
+                if isinstance(writable_rows, int) and writable_rows == 4:
+                    return 4
                 for writable_row in writable_rows:
                     out_writer.writerow(writable_row)
                 gene_results = list()
@@ -585,9 +629,13 @@ def rollup(search_engine: str, search_engine_filepath: str, use_target_list: boo
                 continue
             total_seqs += 1
             raw_seq = row[sequence_index]
+            if len(raw_seq) < 6:
+                continue
+            #print(raw_seq)
             pep_mod_seq = row[modified_sequence_index]
             pep_seq = row[sequence_index].replace("L","I")
             if pep_seq is None:
+                logging.error(f"{search_engine} file is missing pep_seq")
                 print("HALT!")  # A handled exception would be preferable here
                 break
             genes_positions = pep_dict.get(pep_seq)
@@ -612,7 +660,7 @@ def rollup(search_engine: str, search_engine_filepath: str, use_target_list: boo
                 if pep_mod_seq == "":
                     missing_PTM += 1
                     continue
-                new_seq = pep_seq
+                new_seq = raw_seq
                 pep_mod_seq = pep_mod_seq.split('.')[1]
                 i = len(pep_mod_seq) - 1
                 inv_mod_dict = {v:k for k, v in var_mod_dict.items()}
@@ -643,15 +691,16 @@ def rollup(search_engine: str, search_engine_filepath: str, use_target_list: boo
                 new_user_PTMs = [ptm.lower()[:2] for ptm in user_PTMs]
             
             new_pep_mod_seq, new_pep_seq, missed_cleave_fix = clean_pep_seq(cleave_rules[protease], pep_mod_seq, new_user_PTMs, raw_seq)
-            #if raw_seq == "AHEILPNLVCCSAK":
-            #    input(new_pep_mod_seq + ' ' + new_pep_seq + ' ' + str(missed_cleave_fix))
+            #input("old " + pep_mod_seq + ", new " + new_pep_mod_seq)
             if genes_positions and len(genes_positions) == 1:
                 gene, start_pos, unpid, protein_name = list(genes_positions)[0]
                 if not new_pep_mod_seq in mod_dict:
-                    print("\033[91m {}\033[00m".format(f"\n{raw_seq} does not have the PTM(s) selected!"), end='')
+                    #print("\033[91m {}\033[00m".format(f"\n{raw_seq} does not have the PTM(s) selected!"), end='')
                     missing_PTM += 1
                     continue
                 mods = mod_dict[new_pep_mod_seq]
+                #if new_pep_seq == "ACLNPASPIVK":
+                #    input(mods)
                 # Skip any peptide sequences without a user-chosen PTM
                 if not (any(mods) and set([m[0] for m in mods]) & set(user_PTMs)): 
                     missing_PTM += 1
@@ -714,7 +763,7 @@ def rollup(search_engine: str, search_engine_filepath: str, use_target_list: boo
                     if isinstance(match, tuple):  # Checks if this is just a single match.
                         gene = match[0]
                         if not new_pep_mod_seq in mod_dict:
-                            print("\033[91m {}\033[00m".format(f"\n{raw_seq} does not have the PTM(s) selected!"), end='')
+                            #print("\033[91m {}\033[00m".format(f"\n{raw_seq} does not have the PTM(s) selected!"), end='')
                             missing_PTM += 1
                             continue
                         mods = mod_dict[new_pep_mod_seq]
@@ -769,7 +818,7 @@ def rollup(search_engine: str, search_engine_filepath: str, use_target_list: boo
                                         sparql_input.append(tuple((match[2], site, gene)))
                     else:  # There are multiple matches
                         if not new_pep_mod_seq in mod_dict:
-                            print("\033[91m {}\033[00m".format(f"\n{raw_seq} does not have the PTM(s) selected!"), end='')
+                            #print("\033[91m {}\033[00m".format(f"\n{raw_seq} does not have the PTM(s) selected!"), end='')
                             missing_PTM += 1
                             continue
                         mods = mod_dict[new_pep_mod_seq]
@@ -838,7 +887,8 @@ def rollup(search_engine: str, search_engine_filepath: str, use_target_list: boo
         # Adds in the last few results
         if len(gene_results) >= 1:
             writable_rows = batch_write(gene_results, search_engine, user_PTMs, use_quant, 
-                                            intensity_method, intensity_dict, add_annotation, sparql_input)
+                                        intensity_method, intensity_dict, add_annotation, 
+                                        sparql_input, use_target_list)
             for writable_row in writable_rows:
                 out_writer.writerow(writable_row)
             print("\033[92m {}\033[00m".format(f"\n{total_sites} sites rolled-up and written"), end='')
