@@ -27,7 +27,6 @@ def clean_localization_pep_seq(rule: tuple, pep_mod_seqs: list, user_PTMs: list,
         str -- the cleaned peptide
         int -- length of the front part of peptide that was removed
     """
-    #print(user_PTMs)
     # Puts break points for unmodified sequence in a list
     breaks = finditer(rule[0], old_pep_seq)
     cut_unmod_sites = []
@@ -46,6 +45,8 @@ def clean_localization_pep_seq(rule: tuple, pep_mod_seqs: list, user_PTMs: list,
             cut_unmod_peptides.append(old_pep_seq[last_site:i])
             last_site = i
         cut_unmod_peptides.append(old_pep_seq[last_site:])
+    #if old_pep_seq == "KACLNPASPIVK":
+    #    input("peptide split " + str(cut_unmod_peptides))
 
     PTM_cut_peptides = []
     for pep_mod_seq in pep_mod_seqs:
@@ -71,16 +72,17 @@ def clean_localization_pep_seq(rule: tuple, pep_mod_seqs: list, user_PTMs: list,
                 last_site = i
             cut_peptides.append(pep_mod_seq[last_site:])
         PTM_cut_peptides.append(cut_peptides)
-        #print(cut_peptides)
-
-    #print(PTM_cut_peptides)
+    #if old_pep_seq == "KACLNPASPIVK":
+    #    input("peptide split " + str(PTM_cut_peptides))
     try:
         cut_peptides = [s for s in PTM_cut_peptides if s != ""][0]
     except IndexError:
         return None, None, None
-    early_start = len(cut_peptides)
-    late_end = 0
-    for cut_peptides in PTM_cut_peptides:
+    #if old_pep_seq == "KACLNPASPIVK":
+    #    print(cut_peptides)
+    first_start = len(cut_peptides)
+    last_end = 0
+    for cut_peptides in [s for s in PTM_cut_peptides if s != ""]:
     # This gets the range of the first and last pep_slice with a PTM
         start = 0
         while start < len(cut_peptides):
@@ -88,8 +90,8 @@ def clean_localization_pep_seq(rule: tuple, pep_mod_seqs: list, user_PTMs: list,
                 break
             else:
                 start += 1
-        if start < early_start:
-            early_start = start
+        if start < first_start:
+            first_start = start
 
         end = len(cut_peptides) - 1
         while end > start:
@@ -97,16 +99,17 @@ def clean_localization_pep_seq(rule: tuple, pep_mod_seqs: list, user_PTMs: list,
                 break
             else:
                 end -= 1
-        if end > late_end:
-            late_end = end
-
-    if early_start == late_end:
-        new_pep_mod_seqs = [peptide[early_start] for peptide in PTM_cut_peptides if peptide != '']
-        new_pep_seq = cut_unmod_peptides[early_start]
+        if end > last_end:
+            last_end = end
+    #if old_pep_seq == "KACLNPASPIVK":
+    #    input("start end " + str(first_start) + ' ' + str(last_end))
+    if first_start == last_end:
+        new_pep_mod_seqs = [peptide[first_start] for peptide in PTM_cut_peptides if peptide != '']
+        new_pep_seq = cut_unmod_peptides[first_start]
     else:
-        new_pep_mod_seqs = [''.join(peptide[early_start:late_end+1]) for peptide in PTM_cut_peptides if peptide != '']
-        new_pep_seq = ''.join(cut_unmod_peptides[early_start:late_end+1])
-    return new_pep_mod_seqs, new_pep_seq, len(''.join(cut_unmod_peptides[0:early_start]))
+        new_pep_mod_seqs = [''.join(peptide[first_start:last_end+1]) for peptide in PTM_cut_peptides if peptide != '']
+        new_pep_seq = ''.join(cut_unmod_peptides[first_start:last_end+1])
+    return new_pep_mod_seqs, new_pep_seq, len(''.join(cut_unmod_peptides[0:first_start]))
 
 def clean_pep_seq(rule: tuple, pep_mod_seq: str, user_PTMs: list, old_pep_seq: str, is_MQ = False) -> str:
     """Removes the missed cleavages without selected PTMs
@@ -120,14 +123,13 @@ def clean_pep_seq(rule: tuple, pep_mod_seq: str, user_PTMs: list, old_pep_seq: s
     Returns:
         str -- the cleaned peptide
     """
-    #print(user_PTMs)
     # Puts break points for unmodified sequence in a list
     breaks = finditer(rule[0], old_pep_seq)
     cut_unmod_sites = []
     cut_unmod_peptides = []
     for breakp in breaks:
         cut_unmod_sites.append(breakp.start())
-    # Adds the unmodified cut peptides in one at a time
+    # Adds the unmodified cut peptides in the list one at a time
     last_site = 0
     if rule[1].lower() == 'c':
         for i in cut_unmod_sites:
@@ -146,7 +148,7 @@ def clean_pep_seq(rule: tuple, pep_mod_seq: str, user_PTMs: list, old_pep_seq: s
     cut_peptides = []
     for breakp in breaks:
         cut_sites.append(breakp.start())
-    # Adds the cut peptides in one at a time
+    # Adds the cut peptides in the list one at a time
     last_site = 0
     if rule[1].lower() == 'c':
         for i in cut_sites:
@@ -158,7 +160,6 @@ def clean_pep_seq(rule: tuple, pep_mod_seq: str, user_PTMs: list, old_pep_seq: s
             cut_peptides.append(pep_mod_seq[last_site:i])
             last_site = i
         cut_peptides.append(pep_mod_seq[last_site:])
-    #print(cut_peptides)
 
     # This gets the range of the first and last pep_slice with a PTM
     start = 0
@@ -190,11 +191,28 @@ def clean_pep_seq(rule: tuple, pep_mod_seq: str, user_PTMs: list, old_pep_seq: s
     if start == end:
         new_pep_mod_seq = cut_peptides[start]
         new_pep_seq = cut_unmod_peptides[start]
-        #print(new_pep_mod_seq)
     else:
         new_pep_mod_seq = ''.join(cut_peptides[start:end+1])
         new_pep_seq = ''.join(cut_unmod_peptides[start:end+1])
-        #print(new_pep_mod_seq)
+    new_start = start
+    while len(new_pep_seq) < 6:
+        if new_start <= 0:
+            end += 1
+            new_pep_mod_seq = ''.join(cut_peptides[new_start:end+1])
+            new_pep_seq = ''.join(cut_unmod_peptides[new_start:end+1])
+        elif end >= len(cut_unmod_peptides) - 1:
+            new_start -= 1
+            new_pep_mod_seq = ''.join(cut_peptides[new_start:end+1])
+            new_pep_seq = ''.join(cut_unmod_peptides[new_start:end+1])
+        elif len(cut_unmod_peptides[new_start-1]) >= len(cut_unmod_peptides[end+1]):
+            new_start -= 1
+            new_pep_mod_seq = ''.join(cut_peptides[new_start:end+1])
+            new_pep_seq = ''.join(cut_unmod_peptides[new_start:end+1])
+        else:
+            end += 1
+            new_pep_mod_seq = ''.join(cut_peptides[new_start:end+1])
+            new_pep_seq = ''.join(cut_unmod_peptides[new_start:end+1])
+    #input(f"old {pep_mod_seq}, new {new_pep_mod_seq}")
     return new_pep_mod_seq, new_pep_seq, len(''.join(cut_unmod_peptides[0:start]))
 
 def parse_maxquant_summary(infile: str) -> list:
@@ -206,10 +224,7 @@ def parse_maxquant_summary(infile: str) -> list:
         int -- the maximum allowed number of missed cleavages
     """
     mqfile = open(infile, 'r')
-    #outfile = open("mq_parsed.csv", 'w', newline='')
-    #assert infile.endswith(".txt")
     tsvReader = csv.reader(mqfile, delimiter='\t', quotechar='"')
-    #csvWriter = csv.writer(outfile)
     protease = ""
     PTMs = []
     maxMissedCleaves = 0
@@ -220,7 +235,6 @@ def parse_maxquant_summary(infile: str) -> list:
     row = next(tsvReader)
     protease = row[header.index("Enzyme")]
     assert protease != ""
-    #PTMs = row[header.index("Variable modifications")].split(';')  # I might just do this in the evidence file
     maxMissedCleaves = int(row[header.index("Max. missed cleavages")])
     mqfile.close()
     return protease.lower(), maxMissedCleaves
@@ -234,7 +248,7 @@ def parse_mascot(in_file: str) -> list:
         list -- protease {str}, quant_range {tuple}, var_mod_map {dict},
         missed_cleaves {int}
     """
-# We need to parse Mascot file first, because raw Mascot output is difficult to work with
+    # We need to parse Mascot file first, because raw Mascot output is difficult to work with
     print(f"Parsing file {in_file}.")
     with open(in_file) as f, \
         open('quant_parsed.csv', 'w', newline='') as out_file:
@@ -262,8 +276,6 @@ def parse_mascot(in_file: str) -> list:
                     header = row
                     header = [i for i in header if i]
                     second_row = next(file_reader)  # need to normalize headers
-                    #print(header)
-                    #print(second_row)
                     quant_range = (len(header), len(second_row)-1)  #range where there will be quant; appears to skip some
                     header.extend(['SampleQuant' 
                                    for i in range(len(second_row) - len(header))])
@@ -304,7 +316,7 @@ def load_pepdict(proteome_fasta_filepath: str, protease: str, missed_cleavages:
     return pep_dict
 
 
-def digest_if_needed(proteome_fasta_filepath: str, protease: str, missed_cleavages: int, minlen=5, maxlen=55, 
+def digest_if_needed(proteome_fasta_filepath: str, protease: str, missed_cleavages: int, minlen=6, maxlen=55, 
                      m_excise="Both"):
     """Runs digest and dumps pickle file (dict)"""
     seq_list = []  # (gene, organism, sequence, unpid)
