@@ -1,4 +1,7 @@
 """run_proteoSushi.py: The starting point to run proteoSushi"""
+import logging
+import os
+
 try:
     from proteosushi.proteosushi_gui import run_gui
     from proteosushi.combine_intensities import rollup
@@ -8,24 +11,25 @@ except ImportError:  # Allows the program to be run not as a module
 
 
 if __name__ == "__main__":
+    logging.basicConfig(level=logging.WARNING, filename=os.path.join("logs","ps.log"), filemode='w')
     run_gui()
     '''
     rollup(
-        search_engine="maxquant",
-        search_engine_filepath="/home/rob/Documents/Held_Lab/ProteoSushi/proteosushi/examples/txt",
+        search_engine="generic",
+        search_engine_filepath="/home/rob/Documents/Held_Lab/ProteoSushi/proteosushi/examples/EGFR_Skyline_data.csv",
         use_target_list=False,
         target_list_filepath="",
-        max_missed_cleavages=3,
+        max_missed_cleavages=2,
         protease="trypsin/p",
-        fdr_threshold=.01,
-        use_quant=True,
-        user_PTMs=["Carbamidomethyl (C)"],
+        fdr_threshold=None,
+        use_quant=False,
+        user_PTMs=["C[+57]", "C[+IAC/NEM]"],
         proteome_fasta_filepath="/home/rob/Documents/Held_Lab/ProteoSushi/proteosushi/examples/fastas/Uni-Hum-Ref-20141022.fasta",
         intensity_method="sum",
-        add_annotation=False,
+        add_annotation=True,
         species_id="9606",
-        output_filename="/home/rob/Documents/Held_Lab/ProteoSushi/localization_test.csv",
-        localization_threshold=.5
+        output_filename="/home/rob/Documents/Held_Lab/ProteoSushi/proteosushi/output/skyline_output_annotated.csv",
+        localization_threshold=None
     )
     '''
 #EOF
\ No newline at end of file
